@@ -56,7 +56,7 @@ int bindport(const char *hostname, int port) {
 	if (getuid() == 0 && geteuid() != 0) {
 		/* become root again - use our function instead of plain
 		 * setuid() for the logging */
-		log(8, "Changing ID to root (socket(), bind(), pidfile)");
+		log(8, "Changing ID to root (socket(), bind())");
 		changeid("root", UID);
 	}
 	shandle = socket(AF_INET, SOCK_STREAM, tcp_proto);
@@ -83,7 +83,7 @@ int bindport(const char *hostname, int port) {
 	log(6, "Listening on %s, port %d", hostname, port);
 
 	if (getuid() == 0) {
-		log(8, "Changing id back (socket(), bind(), pidfile)");
+		log(8, "Changing id back (socket(), bind())");
 		changeid(get_option("runasuser"), EUID);
 	}
 
@@ -129,6 +129,13 @@ int waitclient(const char* hostnames, struct clientinfo* clntinfo) {
 		daemonize();
 	}
 
+	if (getuid() == 0 && geteuid() != 0) {
+		/* become root again - use our function instead of plain
+		 * setuid() for the logging */
+		log(8, "Changing ID to root (pidfile)");
+		changeid("root", UID);
+	}
+
 	option = get_option("pidfile");
 	if (option) {
 		FILE* pidf = fopen(option, "w");
@@ -142,6 +149,12 @@ int waitclient(const char* hostnames, struct clientinfo* clntinfo) {
 			log(2, "Error creating pidfile %s", option);
 		}
 	}
+
+	if (getuid() == 0) {
+		log(8, "Changing id back (socket(), bind())");
+		changeid(get_option("runasuser"), EUID);
+	}
+
 	/* this has to be done for the daemonization. We do it now after
 	 * the pidfile has been created */
 	umask(0);
