@@ -521,15 +521,16 @@ int secsftp_pass(char* args, struct conn_info_st* conn_info) {
 			} else {
 				char* succ_msg = "230 User %s logged in.\r\n";
 				char* msg = (char*) malloc(strlen(succ_msg) +
-					strlen(conn_info->clntinfo->user));
+					strlen(conn_info->lsforward->fwuser));
 				conn_info->li->respcode = 230;
 				enough_mem(msg);
 				sprintf(msg, succ_msg,
-						conn_info->clntinfo->user);
+						conn_info->lsforward->fwuser);
 				say(cs, msg);
 				free(msg);
 				msg = 0;
 				conn_info->clntinfo->serversocket = 0xff;
+				free_loginst();
 
 				return CMD_HANDLED;
 			}
